==> eiffelstudio-18.01.10.1424.tar: F_code/C7/da325.c <==
/*
 * Code for class DATE_CONSTANTS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "da325.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DATE_CONSTANTS}.days_in_i_th_month */
EIF_INTEGER_32 F372_5400 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLIU(4);
	
	RTGC;
	tr1 = RTOSCF(5408,F372_5408,(Current));
	{
		/* INLINED CODE (at) */
		ti4_1 = (EIF_INTEGER_32)  0;
		tr2 = tr1;
		tr3 = *(EIF_REFERENCE *)(RTCW(tr2));
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(tr2)+ _LNGOFF_1_1_0_1_);
		ti4_1 = 
			/* INLINED CODE (SPECIAL.item) */
			*((EIF_INTEGER_32 *)RTCW(tr3) + ((EIF_INTEGER_32) (arg1 - ti4_2)))
			/* END INLINED CODE */;
		/* END INLINED CODE */
	}
	Result = ti4_1;
	tb1 = '\0';
	if ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 2L))) {
		tb1 = F372_5407(Current, arg2);
	}
	if (tb1) {
		RTLE;
		return (EIF_INTEGER_32) (EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
	}
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.date_default_format_string */
EIF_REFERENCE F372_5401 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(3096,F182_3096,(RTCV(RTOSCF(5359,F368_5359,(Current)))));
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.days_text */
EIF_REFERENCE F372_5402 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(3092,F182_3092,(RTCV(RTOSCF(5359,F368_5359,(Current)))));
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.months_text */
EIF_REFERENCE F372_5403 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(3093,F182_3093,(RTCV(RTOSCF(5359,F368_5359,(Current)))));
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.is_leap_year */
EIF_BOOLEAN F372_5407 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = '\0';
	{
		/* INLINED CODE (mod) */
		ti4_1 = ((EIF_INTEGER_32) 4L);
		ti4_2 = (EIF_INTEGER_32)  0;
		ti4_2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ti4_1);
		if ((EIF_BOOLEAN) (ti4_2 < ((EIF_INTEGER_32) 0L))) {
			ti4_2 += ti4_1;
		}
		/* END INLINED CODE */
	}
	if ((EIF_BOOLEAN)(ti4_2 == ((EIF_INTEGER_32) 0L))) {
		tb1 = '\01';
		{
			/* INLINED CODE (mod) */
			ti4_1 = ((EIF_INTEGER_32) 100L);
			ti4_2 = (EIF_INTEGER_32)  0;
			ti4_2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ti4_1);
			if ((EIF_BOOLEAN) (ti4_2 < ((EIF_INTEGER_32) 0L))) {
				ti4_2 += ti4_1;
			}
			/* END INLINED CODE */
		}
		if (!((EIF_BOOLEAN)(ti4_2 != ((EIF_INTEGER_32) 0L)))) {
			{
				/* INLINED CODE (mod) */
				ti4_1 = ((EIF_INTEGER_32) 400L);
				ti4_2 = (EIF_INTEGER_32)  0;
				ti4_2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ti4_1);
				if ((EIF_BOOLEAN) (ti4_2 < ((EIF_INTEGER_32) 0L))) {
					ti4_2 += ti4_1;
				}
				/* END INLINED CODE */
			}
			tb1 = (EIF_BOOLEAN)(ti4_2 == ((EIF_INTEGER_32) 0L));
		}
		Result = tb1;
	}
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.days_in_months */
static EIF_REFERENCE F372_5408_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (5408);
#define Result RTOSR(5408)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {1813,1977,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr2 = RTLNSP2(typres0.id,0,((EIF_INTEGER_32) 12L),sizeof(EIF_INTEGER_32), EIF_TRUE);
		RT_SPECIAL_COUNT(tr2) = 12L;
	}
	*((EIF_INTEGER_32 *)tr2+0) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+1) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 28L);
	*((EIF_INTEGER_32 *)tr2+2) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+3) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 30L);
	*((EIF_INTEGER_32 *)tr2+4) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+5) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 30L);
	*((EIF_INTEGER_32 *)tr2+6) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+7) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+8) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 30L);
	*((EIF_INTEGER_32 *)tr2+9) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+10) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 30L);
	*((EIF_INTEGER_32 *)tr2+11) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) F1814_17350)(tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (5408);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F372_5408 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(5408,F372_5408_body,(Current));
}

void EIF_Minit325 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C7/da325.c <==
/*
 * Code for class DATE_CONSTANTS
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "da325.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DATE_CONSTANTS}.days_in_i_th_month */
EIF_INTEGER_32 F371_5402 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLIU(4);
	
	RTGC;
	tr1 = RTOSCF(5410,F371_5410, (Current));
	{
		/* INLINED CODE (ARRAY.at) */
		ti4_1 = (EIF_INTEGER_32)  0;
		tr2 = tr1;
		tr3 = *(EIF_REFERENCE *)(RTCW(tr2));
		ti4_1 = 
			/* INLINED CODE (SPECIAL.item) */
			*((EIF_INTEGER_32 *)RTCW(tr3) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(RTCW(tr2)+ _LNGOFF_1_1_0_1_))))
			/* END INLINED CODE */;
		/* END INLINED CODE */
	}
	Result = ti4_1;
	tb1 = '\0';
	if ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 2L))) {
		tb1 = F371_5409(Current, arg2);
	}
	if (tb1) {
		RTLE;
		return (EIF_INTEGER_32) (EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
	}
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.date_default_format_string */
EIF_REFERENCE F371_5403 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(3111,F181_3111, (RTCV(RTOSCF(5361,F367_5361, (Current)))));
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.days_text */
EIF_REFERENCE F371_5404 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(3107,F181_3107, (RTCV(RTOSCF(5361,F367_5361, (Current)))));
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.months_text */
EIF_REFERENCE F371_5405 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	Result = RTOSCF(3108,F181_3108, (RTCV(RTOSCF(5361,F367_5361, (Current)))));
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.is_leap_year */
EIF_BOOLEAN F371_5409 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	Result = '\0';
	{
		/* INLINED CODE (TIME_UTILITY.mod) */
		ti4_1 = ((EIF_INTEGER_32) 4L);
		ti4_2 = (EIF_INTEGER_32)  0;
		ti4_2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ti4_1);
		if ((EIF_BOOLEAN) (ti4_2 < ((EIF_INTEGER_32) 0L))) {
			ti4_2 += ti4_1;
		}
		/* END INLINED CODE */
	}
	if ((EIF_BOOLEAN)(ti4_2 == ((EIF_INTEGER_32) 0L))) {
		tb1 = '\01';
		{
			/* INLINED CODE (TIME_UTILITY.mod) */
			ti4_1 = ((EIF_INTEGER_32) 100L);
			ti4_2 = (EIF_INTEGER_32)  0;
			ti4_2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ti4_1);
			if ((EIF_BOOLEAN) (ti4_2 < ((EIF_INTEGER_32) 0L))) {
				ti4_2 += ti4_1;
			}
			/* END INLINED CODE */
		}
		if (!((EIF_BOOLEAN)(ti4_2 != ((EIF_INTEGER_32) 0L)))) {
			{
				/* INLINED CODE (TIME_UTILITY.mod) */
				ti4_1 = ((EIF_INTEGER_32) 400L);
				ti4_2 = (EIF_INTEGER_32)  0;
				ti4_2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ti4_1);
				if ((EIF_BOOLEAN) (ti4_2 < ((EIF_INTEGER_32) 0L))) {
					ti4_2 += ti4_1;
				}
				/* END INLINED CODE */
			}
			tb1 = (EIF_BOOLEAN)(ti4_2 == ((EIF_INTEGER_32) 0L));
		}
		Result = tb1;
	}
	RTLE;
	return Result;
}

/* {DATE_CONSTANTS}.days_in_months */
static EIF_REFERENCE F371_5410_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	

	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEV;
	RTGC;
	RTOSP (5410);
#define Result RTOSR(5410)
	RTOC_NEW(Result);
	{
		static EIF_TYPE_INDEX typarr0[] = {1884,2020,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr2 = RTLNSP2(typres0.id,0,((EIF_INTEGER_32) 12L),sizeof(EIF_INTEGER_32), EIF_TRUE);
		RT_SPECIAL_COUNT(tr2) = 12L;
	}
	*((EIF_INTEGER_32 *)tr2+0) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+1) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 28L);
	*((EIF_INTEGER_32 *)tr2+2) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+3) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 30L);
	*((EIF_INTEGER_32 *)tr2+4) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+5) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 30L);
	*((EIF_INTEGER_32 *)tr2+6) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+7) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+8) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 30L);
	*((EIF_INTEGER_32 *)tr2+9) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	*((EIF_INTEGER_32 *)tr2+10) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 30L);
	*((EIF_INTEGER_32 *)tr2+11) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 31L);
	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) F1885_18276)(tr2);
	Result = (EIF_REFERENCE) tr1;
	RTOSE (5410);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F371_5410 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(5410,F371_5410_body,(Current));
}

void EIF_Minit325 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
